// ----------------------------------------------------------------------------	-
#ifndef utypesH
#define utypesH
// ----------------------------------------------------------------------------	-

// ============================================================================	=

/* update 03-03-2014 */

/* Program written by Klaus R. Schambeck */

// ============================================================================	=

// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -	-

/*		C and C++ data type definitions
 *   - ----------------------------------------------------------------	-
 * 	"int" and "unsigned int" (uint) types are, by definition, the native
 * 	and most efficient ones on any platform ... therefore use it unless :
 *	1) there is a need to expressively indicate that the value stored
 *	   will be larger than 16 bits (even arm int and uint are 32 bits)
 *	   or for portability reasons.
 *	2) use char and "unsigned char" (uchar) or short and "unsigned short"
 *	   (ushort) if the chosen data type is part of an array in which it
 *	   provides memory space savings, or a struct where there are
 *	   constraints on the organization of data ... matching data struct.
 *	3) quite often the matching communications portion running on a usb
 *	   host is executing the same code as the firmware and it is being
 *	   debugged on the host computer. in this case it is advantageous to
 *	   keep the data types semantics the same.
 */
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -	-

#define cNdkLog 0

#if cNdkLog
#include <android/log.h>
#endif

#include <stdbool.h>

// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -	-

#define cArm !__arm__

#define cQtApp  1

#define ERR_ENA 0x01
#define MSG_ENA 0x02

#if __arm__ == cArm
extern unsigned PrnEna ;

void fprint (const char *form, ...) ;
#define   PRINT(...)			    fprint (__VA_ARGS__)
#define ERR_PRN(...) if (PrnEna >= ERR_ENA) fprint (__VA_ARGS__)
#define MSG_PRN(...) if (PrnEna >= MSG_ENA) fprint (__VA_ARGS__)
#else
extern unsigned MsgEna ;
extern void	MsgPrint (unsigned ena, const char *form, ...) ;

#define ERR_PRN(...)		MsgPrint (ERR_ENA, __VA_ARGS__)
#define MSG_PRN(...)		MsgPrint (MSG_ENA, __VA_ARGS__)
#endif

#define QS2PCH(qs) (qs.toStdString().c_str())

#define PACKED __attribute__((__packed__))

#undef	REG
#define REG	register

#ifndef NULL
#define NULL    ((void *) 0)
#endif

typedef	  signed char	schar ;
typedef unsigned char	uchar ;
typedef unsigned short	ushort ;
typedef unsigned int	uint ;
//typedef unsigned long	ulong ;		/* 64 bit quantity	*/

#undef	_BIT
#define	_BIT(n) (1ul << (n))

#undef	_BITF
#define	_BITF(v, n) ((v) << (n))

// ----------------------------------------------------------------------------	-
#endif	/* utypesH */
// ----------------------------------------------------------------------------	-

